﻿If (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator))
{
  # Relaunch as an elevated process:
  Start-Process powershell.exe "-File",('"{0}"' -f $MyInvocation.MyCommand.Path) -Verb RunAs
  exit
}

Write-Output "*** DTS APO4x Extension Package installation ***"

$RTKAudio = [bool](Get-PnpDevice | Where-Object FriendlyName -eq 'Realtek(R) Audio')
$CmediaAudio = [bool](Get-PnpDevice | Where-Object FriendlyName -eq 'C-Media(R) Audio')
$SoundWireAudio = [bool](Get-PnpDevice | Where-Object FriendlyName -eq 'SoundWire Audio')
$ScriptLocation = Split-Path -Parent $MyInvocation.MyCommand.Definition
Set-Location $ScriptLocation
$InfPath = (Get-ChildItem -Recurse -Include *.inf | Select-String -Pattern "e2f84ce7-8efa-411c-aa69-97454ca4cb57" | Select Path).Path

if ($RTKAudio)
{
    $InstanceId = (Get-PnpDevice | Where-Object FriendlyName -eq 'Realtek(R) Audio' | Where-Object Status -eq 'OK').InstanceId
    $HWID = $InstanceId.split("\\")[0] + "\\" + $InstanceId.split("\\")[1]
    $REV = '&' + $HWID.split("&")[-1]
    $HWID = $HWID -replace $REV, $Null

    Write-Output "Audio HWID: " $HWID

    $Compatible = 0
    Foreach ($Item in $Infpath)
    {
        if ([bool](Get-Content $Item | Select-String -Pattern $HWID))
        {
            cmd.exe /c pnputil /add-driver $Item /install
            $Compatible = 1
        }
    }
    if (-not $Compatible) {Write-Output "This Device is not compatible"}
} 
elseif ($CmediaAudio)
{
    $IntelUsbAudio = [bool](Get-PnpDevice | Select FriendlyName | Select-String -Pattern "Smart Sound Technology for USB Audio")
    if ($IntelUsbAudio)
    {
        $InstanceId = (Get-PnpDevice | Select InstanceId | Select-String -Pattern "INTELAUDIO" | Select-String -Pattern "LINKTYPE_06").Line.split("=")[1]
        $HWID = $InstanceId.split("\\")[0] + "\\" + $InstanceId.split("\\")[1]
        $REV = '&' + $HWID.split("&")[-1]
        $HWID = $HWID -replace $REV, $Null
        
        Write-Output "Audio HWID:" $HWID

        $Compatible = 0
        Foreach ($Item in $Infpath)
        {
            if ([bool](Get-Content $Item | Select-String -Pattern $HWID))
            {
                cmd.exe /c pnputil /add-driver $Item /install
                $Compatible = 1
            }
        }
        if (-not $Compatible) {Write-Output "This Device is not compatible"}
    }
    else
    {
        $InstanceId = (Get-PnpDevice | Where-Object FriendlyName -eq 'C-Media(R) Audio').InstanceId
        $HWID = $InstanceId.split("\\")[0] + "\\" + $InstanceId.split("\\")[1]
        
        Write-Output "Audio HWID:" $HWID
        
        $Compatible = 0
        Foreach ($Item in $Infpath)
        {
            if ([bool](Get-Content $Item | Select-String -Pattern $HWID))
            {
                cmd.exe /c pnputil /add-driver $Item /install
                $Compatible = 1
            }
        }
        if (-not $Compatible) {Write-Output "This Device is not compatible"}
    }
}
elseif ($SoundWireAudio)
{
    $InstanceId = (Get-PnpDevice | Where-Object FriendlyName -eq 'SoundWire Audio' | Where-Object Status -eq 'OK').InstanceId
    $Compatible = 0
    Foreach ($HWID in $InstanceId)
    {
        $HWID = $HWID.split("\\")[0] + "\\" + $HWID.split("\\")[1]
        Write-Output "Audio HWID: " $HWID
        Foreach ($Item in $Infpath)
        {
            if ([bool](Get-Content $Item | Select-String -Pattern $HWID))
            {
                Write-Output "Audio HWID: " $HWID
                cmd.exe /c pnputil /add-driver $Item /install
                $Compatible = 1
                break
            }
        }
        if ($Compatible) {break}
    }
    if (-not $Compatible) {Write-Output "This Device is not compatible"}
}
else
{
    Foreach ($Item in $Infpath)
    {
        cmd.exe /c pnputil /add-driver $Item /install
    }
}


Write-Output "*** DTS APO4x Core Package installation ***"
pnputil -a "DTS_UWP_APO4x_Core_MSFT_SIGNED_1_14_0_0_21H1_21H2_22H2\dtsapo4x64.inf" /install

Write-Output "*** DTS APO4x Service installation ***"
pnputil -a "DTS_UWP_APO4x_RPCService_MSFT_SIGNED_1_14_3_0_21H1_21H2_22H2\dtsapo4xservice.inf" /install

Write-Output "*** DTS:X Ultra HSA SWC installation ***"
pnputil -a "DTSXUltra_UWP_APO4x_HSA_MSFT_SIGNED_1_11_5_0_21H1_21H2_22H2\dtsapo4xultrahsa.inf" /install

Write-Output "*** DISM install DTS:X Ultra package ***"
Set-Location DTSXUltraHSA_1.12.0.0_x64_bundle.appxupload_Windows10_PreinstallKit
dism.exe /online /Add-ProvisionedAppxPackage /PackagePath:"c640e445200c480e8b9c78a582465053.appxbundle" /LicensePath:"c640e445200c480e8b9c78a582465053_License1.xml" /DependencyPackagePath:"Microsoft.NET.Native.Framework.1.7_1.7.27413.0_x64__8wekyb3d8bbwe.appx" /DependencyPackagePath:"Microsoft.NET.Native.Runtime.1.7_1.7.27422.0_x64__8wekyb3d8bbwe.appx" /DependencyPackagePath:"Microsoft.VCLibs.140.00_14.0.32530.0_x64__8wekyb3d8bbwe.appx" /Region:"all" 
Set-Location ..

Write-Output "*** DISM install DTS Sound Unbound package ***"
Set-Location DtsSoundUnbound_Release_v2023.4.6.0_rebundled.appxbundle_Windows10_PreinstallKit
dism.exe /online /Add-ProvisionedAppxPackage /PackagePath:"291b888935fa430cb3ff3f2b4232c9ee.appxbundle" /LicensePath:"291b888935fa430cb3ff3f2b4232c9ee_License1.xml" /DependencyPackagePath:"Microsoft.NET.Native.Framework.2.2_2.2.29512.0_x64__8wekyb3d8bbwe.appx" /DependencyPackagePath:"Microsoft.NET.Native.Runtime.2.2_2.2.28604.0_x64__8wekyb3d8bbwe.appx" /DependencyPackagePath:"Microsoft.VCLibs.140.00_14.0.32530.0_x64__8wekyb3d8bbwe.appx" /Region:"all" 
Set-Location ..

Write-Output "Done"
pause